.. _api:

API Reference
=============

.. automodule:: pymapd
   :members: connect, Connection, Cursor

Exceptions
----------

.. automodule:: pymapd.exceptions
   :members: Error, InterfaceError, DatabaseError, OperationalError, IntegrityError, InternalError, ProgrammingError, NotSupportedError
